summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJens Axboe <axboe@kernel.dk>2020-01-28 12:54:25 -0700
committerJens Axboe <axboe@kernel.dk>2020-01-28 12:54:25 -0700
commit23a147871090999a209556f3efb6522dd85a9220 (patch)
tree1bdc8a2a231d8bbdd29e524346427ee20fb417b4
parentdd08a9e22393c8ff3b69904ee283f74f7e5c903d (diff)
downloadliburing-23a147871090999a209556f3efb6522dd85a9220.tar.gz
liburing-23a147871090999a209556f3efb6522dd85a9220.tar.bz2
Add sqe personality member/flag
Signed-off-by: Jens Axboe <axboe@kernel.dk>
-rw-r--r--src/include/liburing/io_uring.h10
1 files changed, 9 insertions, 1 deletions
diff --git a/src/include/liburing/io_uring.h b/src/include/liburing/io_uring.h
index 79c75a4..9148422 100644
--- a/src/include/liburing/io_uring.h
+++ b/src/include/liburing/io_uring.h
@@ -40,7 +40,12 @@ struct io_uring_sqe {
};
__u64 user_data; /* data to be passed back at completion time */
union {
- __u16 buf_index; /* index into fixed buffers, if used */
+ struct {
+ /* index into fixed buffers, if used */
+ __u16 buf_index;
+ /* personality to use */
+ __u16 personality;
+ };
__u64 __pad2[3];
};
};
@@ -51,6 +56,7 @@ enum {
IOSQE_IO_LINK_BIT,
IOSQE_IO_HARDLINK_BIT,
IOSQE_ASYNC_BIT,
+ IOSQE_PERSONALITY_BIT,
};
/*
@@ -66,6 +72,8 @@ enum {
#define IOSQE_IO_HARDLINK (1U << IOSQE_IO_HARDLINK_BIT)
/* always go async */
#define IOSQE_ASYNC (1U << IOSQE_ASYNC_BIT)
+/* use specified personality */
+#define IOSQE_PERSONALITY (1U << IOSQE_PERSONALITY_BIT)
/*
* io_uring_setup() flags